@@ -703,7 +703,7 @@ subroutine lmdif ( fcn, m, n, x, fvec, ftol, xtol, gtol, maxfev, epsfcn, &
   return
 end
 !
-subroutine lmdif1 ( fcn, m, n, x, fvec, tol, info, xd, yd, syd, model )
+subroutine lmdif1 ( fcn, m, n, x, fvec, tol, info, xd, yd, syd, model, hess )
 
 !*****************************************************************************80
 !
@@ -808,8 +808,9 @@ subroutine lmdif1 ( fcn, m, n, x, fvec, tol, info, xd, yd, syd, model )
   real ( kind = 8 ) tol
   real ( kind = 8 ) x(n)
   real ( kind = 8 ) xtol
-  real ( kind = 8 ) xd(m), yd(m), syd(m)
-  integer ( kind = 4 ) model
+  real ( kind = 8 ) xd(m), yd(m), syd(m), hess(n,n)
+  real ( kind = 8 ) perm(n,n), rrr(n,n)
+  integer ( kind = 4 ) model, i, j
 
   info = 0
 
@@ -838,6 +839,24 @@ subroutine lmdif1 ( fcn, m, n, x, fvec, tol, info, xd, yd, syd, model )
     info = 4
   end if
 
+  do j = 0, n-1
+      do i = 0, n-1
+          if (i+1==ipvt(j+1)) then
+              perm(i+1,j+1) = 1.0
+          else  
+              perm(i+1,j+1) = 0.0
+          end if
+
+          if (i<=j) then
+              rrr(i+1,j+1) = fjac(i+1,j+1)
+          else 
+              rrr(i+1,j+1) = 0.0
+          end if
+      end do
+  end do
+
+  hess = matmul(perm,matmul(matmul(transpose(rrr),rrr), transpose(perm)))
+
   return
 end
 !
